# Python Template Repo
Quick Setup
- [x] update setup.py (name)
- [x] update setup.cfg (versionfile_source, versionfile_build)
- [x] rename folder of package
- [x] `pip install versioneer` and `versioneer install`

Optional for codecov
- [ ] create token on codecov.com and add is as `CODECOV_TOKEN`
- [ ] uncomment `Upload coverage to Codecov` in `.github/workflows.unittests.yml`


Additional TODO Transforms:
- [ ] Seg to Bbox trafo
- [ ] One hot trafo
